.. _`API Reference`:

API Reference
=============

.. toctree::
   :maxdepth: 1

   ble_hci
   ble_standard
   constants
   data_params
   hci_packets
   packet_codes
   packet_defs
   utils
   vendor_spec

Package Contents
----------------

.. automodule:: max_ble_hci
   :members:
   :undoc-members:
   :show-inheritance: